@@ -1,3 +1,4 @@
+/* $Id: pager.c,v 1.6 2001/06/09 09:25:49 amai Exp $ */
 /****************************************************************************
  * This module is all new
  * by Rob Nation 
@@ -7,8 +8,16 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
+#include <LTconfig.h>
+
+#include <string.h>
+
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
 #include "mwm.h"
 
+
 Bool pagerOn = True;
 Bool EnablePagerRedraw = True;
 Bool DoHandlePageing = True;
