@@ -1,3 +1,4 @@
+/* $Id: resize.c,v 1.7 2001/10/24 12:06:44 amai Exp $ */
 /*****************************************************************************/
 /**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
 /**                          Salt Lake City, Utah                           **/
@@ -33,8 +34,17 @@
  * mwm - "LessTif Window Manager"
  ***********************************************************************/
 
+#include <LTconfig.h>
+
+#include <stdio.h>
+#include <string.h>
+
+#include <Xm/Xm.h>
+#include <Xm/MwmUtil.h>
+
 #include "mwm.h"
 
+
 static int dragx;		/* all these variables are used */
 static int dragy;		/* in resize operations */
 static int dragWidth;
@@ -47,7 +57,6 @@ static int origHeight;
 
 static int ymotion, xmotion;
 static int last_width, last_height;
-extern int menuFromFrameOrWindowOrTitlebar;
 
 /*
  * display the size in the dimensions window
@@ -78,7 +87,7 @@ display_size(ScreenInfo *scr, MwmWindow *tmp_win, int width, int height,
     dwidth /= tmp_win->hints.width_inc;
     dheight /= tmp_win->hints.height_inc;
 
-    (void)sprintf(str, " %4d x %-4d ", dwidth, dheight);
+    sprintf(str, " %4d x %-4d ", dwidth, dheight);
     offset = (ssw + SIZE_HINDENT * 2 -
 	      XTextWidth(scr->components[MWM_FEEDBACK].font,
 			 str, strlen(str))) / 2;
@@ -233,9 +242,7 @@ RESIZE_EventLoop(ScreenInfo *scr, Window w, MwmWindow *tmp_win,
     Bool finished = False, done = False;
     int x, y, delta_x, delta_y;
     Window ResizeWindow;
-    extern int Stashed_X, Stashed_Y;
     XEvent oevent;
-    extern Bool pagerOn;
 
     if ((w == None) || (tmp_win == NULL))
 	return;
