@@ -1,8 +1,9 @@
 /**
  *
- * $Id: DrawingAP.h,v 1.1 1998/10/06 18:40:57 pgw Exp $
+ * $Id: DrawingAP.h,v 1.3 2000/09/23 14:51:40 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef XM_DRAWINGA_P_H
-#define XM_DRAWINGA_P_H
+#ifndef _XM_DRAWINGAP_H
+#define _XM_DRAWINGAP_H
 
 #include <Xm/ManagerP.h>
 #include <Xm/DrawingA.h>
@@ -45,13 +46,6 @@ typedef struct {
     XtCallbackList input_callback;
 
     unsigned char resize_policy;
-
-#if LESSTIF_BACK_COMPAT
-#else
-    XtCallbackList convert_callback; /* new for 2.0 */
-    XtCallbackList destination_callback; /* new for 2.0 */
-#endif
-
 } XmDrawingAreaPart;
 
 /* Define the full instance record */
@@ -89,4 +83,4 @@ void _XmDrawingAreaInput(Widget wid, XEvent *event,
 }
 #endif
 
-#endif /* XM_DRAWINGA_P_H */
+#endif /* _XM_DRAWINGAP_H */
