@@ -1,8 +1,9 @@
 /**
  *
- * $Id: GadgetP.h,v 1.1 1998/12/29 13:13:59 pgw Exp $
+ * $Id: GadgetP.h,v 1.3 2000/09/23 14:51:40 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
+ * Copyright (C) 1995-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef XM_GADGET_P_H
-#define XM_GADGET_P_H
+#ifndef _XM_GADGETP_H
+#define _XM_GADGETP_H
 
 #include <Xm/XmP.h>
 
@@ -91,12 +92,6 @@ typedef struct _XmGadgetPart {
     Boolean visible;
 
     Mask event_mask; /* the events about which this gadget wants to be notified */
-
-#if LESSTIF_BACK_COMPAT
-#else
-    XmDirection layout_direction; /* new for 2.0 */
-#endif
-
 } XmGadgetPart;
 
 /* Define the full instance record */
@@ -116,10 +111,6 @@ typedef struct _XmGadgetClassExtRec {
     Cardinal record_size;
     XmWidgetBaselineProc widget_baseline;
     XmWidgetDisplayRectProc widget_display_rect;
-#if LESSTIF_BACK_COMPAT
-#else
-    XmWidgetMarginsProc widget_margins; /* new for 2.0 */
-#endif
 } XmGadgetClassExtRec, *XmGadgetClassExt;
 
 #define XmGadgetClassExtVersion 1L
@@ -168,5 +159,5 @@ void _XmBuildGadgetResources(WidgetClass c);
 }
 #endif
 
-#endif /* XM_GADGET_P_H */
+#endif /* _XM_GADGETP_H */
 
