@@ -1,9 +1,9 @@
 /**
  *
- * $Id: MacrosI.h,v 1.41 2000/09/23 17:00:49 amai Exp $
+ * $Id: MacrosI.h,v 1.43 2002/03/29 16:50:43 amai Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2000 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -463,6 +463,9 @@
 #define VSEP_ImHeightSet(o) \
 	(((XmVendorShellExtObject)o)->vendor.im_vs_height_set)
 
+#define Vendor_IconPixmap(o) \
+	(((WMShellWidget)o)->wm.wm_hints.icon_pixmap)
+
 /*
  * ARROW BUTTON WIDGET ACCESS MACROS
  */
@@ -1495,8 +1498,13 @@
 #define List_SelectedItems(w) \
     (((XmListWidget)(w))->list.selectedItems)
 
+#if XmVERSION > 1
+#define List_SelectedIndices(w) \
+    (((XmListWidget)(w))->list.selectedPositions)
+#else
 #define List_SelectedIndices(w) \
     (((XmListWidget)(w))->list.selectedIndices)
+#endif
 
 #define List_MarginHeight(w) \
     (((XmListWidget)(w))->list.margin_height)
