@@ -1,8 +1,8 @@
 /**
  * 
- * $Id: CSTextP.h,v 1.1 2000/08/22 14:23:16 dannybackx Exp $
+ * $Id: CSTextP.h,v 1.2 2001/02/10 15:03:19 amai Exp $
  *
- * Copyright (C) 2000 LessTif Development Team
+ * Copyright (C) 2000, 2001 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -37,14 +37,25 @@
 extern "C" {
 #endif
 
+typedef struct _XmCSTextPart {
+  int dummy;
+} XmCSTextPart;
+
 typedef struct _XmCSTextRec {
     CorePart core;
     XmPrimitivePart primitive;
+    XmCSTextPart cstext;
 } XmCSTextRec;
 
+/* Define class part structure */
+typedef struct {
+    XtPointer extension;
+} CSTextClassPart;
+
 typedef struct _XmCSTextClassRec {
   CoreClassPart core_class;
   XmPrimitiveClassPart primitive_class;
+  CSTextClassPart cstext_class;
 } XmCSTextClassRec;
 
 extern XmCSTextClassRec xmCSTextClassRec;
