@@ -1,6 +1,6 @@
 /**
  * 
- * $Id: ComboBoxP.h,v 1.3 2000/09/23 14:51:42 amai Exp $
+ * $Id: ComboBoxP.h,v 1.4 2001/01/26 10:18:33 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
  * Copyright (C) 1997-2000 LessTif Development Team
@@ -64,8 +64,11 @@ typedef struct _XmComboBoxPart {
    Boolean arrow_pressed;
    Boolean highlighted;
    Boolean scrolling;
-   XtEnum shell_state;
-   Boolean text_changed;
+   XtEnum shell_state;    /* unused ?! */
+   Boolean text_changed;  /* unused ?! */
+#if XmVersion >= 2001
+   XtEnum position_mode;
+#endif   
 } XmComboBoxPart;
 
 /* Define the full instance record */
@@ -129,6 +132,11 @@ extern XmComboBoxClassRec xmComboBoxClassRec;
 #define CB_MatchBehavior(w) \
         (((XmComboBoxWidget)(w))->combo_box.match_behavior)
 
+#if XmVersion >= 2001
+#define CB_PositionMode(w) \
+        (((XmComboBoxWidget)(w))->combo_box.position_modeXmCpositionMode)
+#endif
+
 #define CB_RenderTable(w) \
         (((XmComboBoxWidget)(w))->combo_box.render_table)
 
@@ -144,8 +152,10 @@ extern XmComboBoxClassRec xmComboBoxClassRec;
 #define CB_SelectionCB(w) \
         (((XmComboBoxWidget)(w))->combo_box.selection_callback)
 
+#if XmVersion == 2000
 #define CB_ShellState(w) \
         (((XmComboBoxWidget)(w))->combo_box.shell_state)
+#endif
 
 #define CB_TextChanged(w) \
         (((XmComboBoxWidget)(w))->combo_box.text_changed)
