@@ -1,8 +1,9 @@
 /**
  * 
- * $Id: GrabShell.h,v 1.2 1997/05/27 19:28:44 miers Exp $
+ * $Id: GrabShell.h,v 1.3 2000/09/23 14:51:42 amai Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
+ * Copyright (C) 1997-2000 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,8 +23,8 @@
  *
  **/
 
-#ifndef XM_GRABSHELL_H
-#define XM_GRABSHELL_H
+#ifndef _XM_GRABSHELL_H
+#define _XM_GRABSHELL_H
 
 #include <Xm/Xm.h>
 
@@ -50,5 +51,4 @@ Widget XmCreateGrabShell(Widget parent,
 }
 #endif
 
-#endif
-
+#endif /* _XM_GRABSHELL_H */
