@@ -1,9 +1,9 @@
 /**
  *
- * $Id: DebugUtil.h,v 1.41 2001/12/14 12:14:21 amai Exp $
+ * $Id: DebugUtil.h,v 1.46 2003/08/03 13:24:34 dannybackx Exp $
  * 
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright (C) 1995-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -26,7 +26,7 @@
 #ifndef _XMI_DEBUGUTIL_H
 #define _XMI_DEBUGUTIL_H
 
-#include <LTconfig.h>
+/* #include <LTconfig.h> */
 
 #include <Xm/XmP.h>
 
@@ -64,6 +64,7 @@ const char *_LtDebugEventType2String(int type);
 const char *_LtDebugComboBoxType2String(unsigned char type);
 #endif
 const char *_LtDebugGeoAction2String(int action);
+const char *_LtDebugDeleteResponse2String(int d);
 const char *_LtDebugGeometryResult2String(XtGeometryResult r);
 const char *_LtDebugDragAndDropMessageType2String(unsigned char r);
 const char *_LtDebugDragType2String(unsigned char r);
@@ -72,6 +73,7 @@ const char *_LtDebugWidgetGeometry2String(XtWidgetGeometry *g);
 const char *_LtDebugAttachment2String(int i);
 const char *_LtDebugMenuFocusOp2String(int f);
 const char *_LtDebugMenuEnum2String(int f);
+const char *_LtDebugMwmInput2String(int a);
 const char *_LtDebugBoolean2String(Boolean b);
 const char *_LtDebugXmString2String(XmString xms);
 const char *_LtDebugPacking2String(unsigned char p);
@@ -110,7 +112,7 @@ void _LtDebugAction(const char *fn, Widget w, const String action,
 #define DEBUGOUT(x)
 
 #ifdef	USE_DMALLOC
-# undef	USE_DMALLOC
+#undef	USE_DMALLOC
 #endif
 #else
 Boolean _LtDebugInDebug(const char *fn, Widget w);
@@ -122,10 +124,16 @@ Boolean _LtDebugInDebug(const char *fn, Widget w);
  * Check the INSTALL(.html) doc for references about the
  * dmalloc package!
  */
-#ifdef	WITH_DMALLOC
+#ifdef WITH_DMALLOC
 
 #include <dmalloc.h>
 
+/* Our Xt*alloc() replacements */
+XtPointer   _LtDebugMalloc(const char *f,  int l, Cardinal size);
+XtPointer   _LtDebugCalloc(const char *f,  int l, Cardinal count, Cardinal size);
+XtPointer   _LtDebugRealloc(const char *f, int l, XtPointer p, Cardinal size);
+void        _LtDebugFree(const char *f,    int l, XtPointer p);
+
 #ifdef	XtMalloc
 #undef	XtMalloc
 #endif
@@ -143,11 +151,12 @@ Boolean _LtDebugInDebug(const char *fn, Widget w);
 #endif
 #define	XtFree(x)	_LtDebugFree(__FILE__, __LINE__, x)
 
+#else
+#ifdef WITH_DBMALLOC
+#include <dbmalloc.h>
+#endif	/* WITH_DBMALLOC */
+
 #endif	/* WITH_DMALLOC */
 
-XtPointer   _LtDebugMalloc(char *f,  int l, Cardinal size);
-XtPointer   _LtDebugCalloc(char *f,  int l, Cardinal count, Cardinal size);
-XtPointer   _LtDebugRealloc(char *f, int l, XtPointer p, Cardinal size);
-void        _LtDebugFree(char *f,    int l, XtPointer p);
 
 #endif /* _XMI_DEBUGUTIL_H */
