@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Mrm.c,v 1.32 2001/09/06 12:38:41 amai Exp $
+ * $Id: Mrm.c,v 1.33 2002/02/26 20:22:07 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright (C) 1995-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -46,6 +46,14 @@
 
 #include <XmI/DebugUtil.h>
 
+#ifndef X_LIB_PATH
+#define X_LIB_PATH "/usr/X11/lib"
+#endif
+
+#ifndef LESSTIFHOME
+#define LESSTIFHOME "/usr/local"
+#endif
+
 /*
  * Macros and types
  */
@@ -730,7 +738,7 @@ MakePixmap(Display *d, Pixmap *pixmap, PixmapType * data, Pixel fg,
     andrew[0] = Header;
     for (i = 0; i < NumColors; i++)
 	andrew[i + 1] = ColorTable[i].StringXPM;
-    for (i = 0; i < data->width; i++)
+    for (i = 0; i < (int)data->width; i++)
 	andrew[i + NumColors + 1] = &data->data[i * data->width];
     Image = data->data;
 
@@ -738,9 +746,9 @@ MakePixmap(Display *d, Pixmap *pixmap, PixmapType * data, Pixel fg,
      * value in XmGetPixmapByDepth are totally made up. */
     *pixmap = XCreatePixmap(display, window, data->width, data->height,
 			    DefaultDepth(display, 0));
-    for (i = 0; i < data->height; i++)
+    for (i = 0; i < (int)data->height; i++)
     {
-	for (j = 0; j < data->width; j++)
+	for (j = 0; j < (int)data->width; j++)
 	{
 	    Index = -1;
 	    for (k = 0; k < NumColors; k++)
