@@ -1,11 +1,11 @@
 /**
  *
- * $Id: DialogS.c,v 1.30 2001/07/27 18:51:55 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/DialogS.c,v 1.35 2002/04/12 21:07:02 amai Exp $
  *
  * derived from Xt Vendor class.c 
  *
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
  * Copyright 1989 Massachusetts Institute of Technology
  *
  * This file is part of the GNU LessTif Library.
@@ -26,7 +26,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: DialogS.c,v 1.30 2001/07/27 18:51:55 dannybackx Exp $";
+static const char rcsid[] = "$Header: /cvsroot/lesstif/lesstif/lib/Xm/DialogS.c,v 1.35 2002/04/12 21:07:02 amai Exp $";
 
 /*
  * This controls questionable behavior.  It will go away
@@ -44,35 +44,27 @@ static const char rcsid[] = "$Id: DialogS.c,v 1.30 2001/07/27 18:51:55 dannyback
 #include <Xm/ExtObjectP.h>
 #include <Xm/DialogSP.h>
 #include <Xm/DialogSEP.h>
-#include <X11/StringDefs.h>
-#include <X11/ShellP.h>
 #include <Xm/VendorSP.h>
 #include <Xm/VendorSEP.h>
 #include <Xm/BulletinBP.h>
 #include <Xm/DisplayP.h>
+#include <X11/StringDefs.h>
+#include <X11/ShellP.h>
 
 #include <XmI/DebugUtil.h>
 
 
 static void class_initialize(void);
-
 static void class_part_initialize(WidgetClass wclass);
-
 static void initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void change_managed(Widget w);
-
 static void insert_child(Widget w);
-
 static void delete_child(Widget w);
-
 static void StructureNotifyHandler(Widget w, XtPointer closure,
 				   XEvent *event, Boolean *cont);
-
 static void WmProtocolHandler(Widget w, XtPointer client, XtPointer call);
 
-/* *INDENT-OFF* */
 static XmBaseClassExtRec _XmDialogSCoreClassExtRec = {
     /* next_extension            */ NULL,
     /* record_type               */ NULLQUARK,                             
@@ -244,7 +236,6 @@ XmDialogShellExtClassRec xmDialogShellExtClassRec = {
 	/* extension          */ NULL
     }
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmDialogShellExtObjectClass = (WidgetClass)&xmDialogShellExtClassRec;
@@ -461,9 +452,10 @@ change_managed(Widget w)
 	 * fixes certain cases (like nedit->open->ok, with no file selected).
 	 */
 	DEBUGOUT(_LtDebug(__FILE__, w, "XtUnmapWidget\n"));
-	if (XmIsBulletinBoard(child))
+	if (XmIsBulletinBoard(child)) {
 		_XmBulletinBoardUnmap(child);
-
+		_LtVendorUnmap(child);	/* To undo grabs */
+	}
 	XtUnmapWidget(w);
     }
 }
