@@ -1,9 +1,9 @@
 /**
  *
- * $Id: PushBG.c,v 1.89 2001/09/13 13:34:13 amai Exp $
+ * $Id: PushBG.c,v 1.96 2003/10/06 16:09:09 dannybackx Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright  1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: PushBG.c,v 1.89 2001/09/13 13:34:13 amai Exp $";
+static const char rcsid[] = "$Id: PushBG.c,v 1.96 2003/10/06 16:09:09 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -45,6 +45,12 @@ static const char rcsid[] = "$Id: PushBG.c,v 1.89 2001/09/13 13:34:13 amai Exp $
 #include <Xm/LabelP.h>
 #include <X11/ShellP.h>
 
+#if XmVERSION > 1
+#include <Xm/TraitP.h>
+#include <Xm/ActivatableT.h>
+#include <Xm/ContItemT.h>
+#endif
+
 #include <XmI/DebugUtil.h>
 
 /*
@@ -53,10 +59,6 @@ static const char rcsid[] = "$Id: PushBG.c,v 1.89 2001/09/13 13:34:13 amai Exp $
  * Try to add trait stuff by #ifdeffing it.
  */
 #if XmVERSION > 1
-#include <Xm/TraitP.h>
-#include <Xm/ActivatableT.h>
-#include <Xm/ContItemT.h>
-
 void _XmPushBG_TraitAddCallback(Widget, XtCallbackProc, XtPointer, Boolean);
 
 static XmActivatableTraitRec _XmPushBGTraitRec = {
@@ -74,9 +76,6 @@ static XmContainerItemTraitRec _XmPushBG_ContainerItemTrait = {
 };
 #endif
 
-#ifndef XmUNSPECIFIED
-#define XmUNSPECIFIED (~0)
-#endif
 
 /* Forward Declarations */
 
@@ -486,9 +485,10 @@ secondary_object_create(Widget request, Widget new_w,
 int
 _XmPushBCacheCompare(XtPointer A, XtPointer B)
 {
-    return !memcmp(((XmPushButtonGCacheObjPart *)A),
-		 ((XmPushButtonGCacheObjPart *)B),
-		 sizeof(XmPushButtonGCacheObjPart));
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "_XmPushBCacheCompare\n"));
+
+	return !memcmp(((XmPushButtonGCacheObjPart *)A), ((XmPushButtonGCacheObjPart *)B),
+		sizeof(XmPushButtonGCacheObjPart));
 }
 
 /******************************* GADGET PART *********************************/
@@ -499,6 +499,8 @@ class_initialize(void)
     int ncom;
     Cardinal nlabels;
 
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmPushButtonGadget class_initialize\n"));
+
     /* don't let the nulls fool you.  look at the header file -- the arg
      * isn't used. */
     ClassCacheHead(PBG_ClassCachePart(NULL)).prev =
@@ -549,7 +551,9 @@ class_initialize(void)
 static void
 class_part_initialize(WidgetClass widget_class)
 {
-    _XmFastSubclassInit(widget_class, XmPUSH_BUTTON_GADGET_BIT);
+	DEBUGOUT(_LtDebug(__FILE__, NULL, "XmPushButtonGadget class_part_initialize\n"));
+
+	_XmFastSubclassInit(widget_class, XmPUSH_BUTTON_GADGET_BIT);
 }
 
 static void
@@ -558,6 +562,8 @@ CreateFillGC(Widget w)
     XGCValues values;
     XtGCMask mask;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmPushButtonGadget CreateFillGC\n"));
+
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask;
 
@@ -578,6 +584,8 @@ CreateBackgroundGC(Widget w)
     XGCValues values;
     XtGCMask mask;
 
+	DEBUGOUT(_LtDebug(__FILE__, w, "XmPushButtonGadget CreateBackgroundGC\n"));
+
     mask = GCForeground | GCBackground | GCFillStyle | GCFunction |
 	GCSubwindowMode | GCGraphicsExposures | GCPlaneMask;
 
@@ -644,6 +652,8 @@ initialize(Widget request, Widget new_w,
 {
     Dimension margin, width, height;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG Initialize\n"));
+
     if (!XtIsSubclass(XtParent(new_w), xmManagerWidgetClass))
     {
 	_XmError(new_w, "parent should be manager.");
@@ -760,6 +770,8 @@ initialize(Widget request, Widget new_w,
 static void
 destroy(Widget w)
 {
+    DEBUGOUT(_LtDebug(__FILE__, w, "PushBG Destroy\n"));
+
     if (PBG_Timer(w) != 0)
     {
 	XtRemoveTimeOut(PBG_Timer(w));
@@ -780,6 +792,8 @@ set_values_prehook(Widget old, Widget request, Widget new_w,
     Cardinal size;
     XtPointer nsec, rsec;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG set_values_prehook\n"));
+
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
     size = (*bce)->secondaryObjectClass->core_class.widget_size;
 
@@ -835,6 +849,8 @@ set_values_posthook(Widget old, Widget request, Widget new_w,
 {
     XmWidgetExtData ext;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG set_values_posthook\n"));
+
     /* Gaaaa.  Forgot the CachePart copy!!! */
     if (!_XmLabelCacheCompare((XtPointer)LabG_Cache(new_w),
 			      (XtPointer)LabG_Cache(old)))
@@ -882,8 +898,9 @@ static Boolean
 set_values(Widget old, Widget request, Widget new_w,
 	   ArgList args, Cardinal *num_args)
 {
-    Boolean refresh_needed = False;
-    Dimension margin, width, height;
+	Boolean		refresh_needed = False;
+	Dimension	margin, width, height;
+	XGCValues	gcv;
 
     DEBUGOUT(_LtDebug(__FILE__, new_w,
 		      "set_values: %i args\n"
@@ -915,14 +932,18 @@ set_values(Widget old, Widget request, Widget new_w,
 	CreateFillGC(new_w);
 	refresh_needed = True;
     }
+	/* See bug #772755 : need to query the old widget's values */
+	XGetGCValues(XtDisplayOfObject(old), LabG_NormalGC(old), GCBackground, &gcv);
+/*
     if (XmParentBackground(new_w) != XmParentBackground(old) ||
-	CoreBackgroundPixmap(XtParent(new_w)) !=
-	CoreBackgroundPixmap(XtParent(old)))
-    {
-	XtReleaseGC(new_w, PBG_BackgroundGC(new_w));
-	CreateBackgroundGC(new_w);
-	refresh_needed = True;
-    }
+ */
+	if (XmParentBackground(new_w) != gcv.background ||
+	    CoreBackgroundPixmap(XtParent(new_w)) != CoreBackgroundPixmap(XtParent(old)))
+	{
+		XtReleaseGC(new_w, PBG_BackgroundGC(new_w));
+		CreateBackgroundGC(new_w);
+		refresh_needed = True;
+	}
 
     if (IN_MENU(new_w))
     {
@@ -1091,6 +1112,8 @@ get_values_prehook(Widget new_w, ArgList args, Cardinal *num_args)
     Cardinal size;
     XtPointer nsec;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG get_values_prehook\n"));
+
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
     size = (*bce)->secondaryObjectClass->core_class.widget_size;
 
@@ -1135,6 +1158,8 @@ get_values_posthook(Widget new_w, ArgList args, Cardinal *num_args)
 {
     XmWidgetExtData ext;
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "PushBG get_values_posthook\n"));
+
     _XmPopWidgetExtData(new_w, &ext, XmCACHE_EXTENSION);
 
     _XmExtObjFree((XtPointer)ext->widget);
@@ -1155,8 +1180,7 @@ expose(Widget w, XEvent *event, Region region)
 {
     Dimension inset;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "PBG expose: XY %d %d\n",
-		      XtX(w), XtY(w)));
+    DEBUGOUT(_LtDebug(__FILE__, w, "PBG expose: XY %d %d\n", XtX(w), XtY(w)));
 
     if (!IN_MENU(w))
     {
@@ -1886,8 +1910,10 @@ XmCreatePushButtonGadget(Widget parent, char *name,
 {
 	Widget	r;
 	_XmObjectLock(parent);
+	DEBUGOUT(_LtDebug(__FILE__, parent, "XmCreatePushButtonGadget(%s)\n", name));
 	r = XtCreateWidget(name, xmPushButtonGadgetClass, parent,
 			  arglist, argcount);
+	DEBUGOUT(_LtDebug2(__FILE__, parent, r, "XmCreatePushButtonGadget => %p\n", r));
 	_XmObjectUnlock(parent);
 	return r;
 }
