@@ -1,9 +1,9 @@
 /**
  *
- * $Id: RepType.c,v 1.20 2001/07/27 18:51:57 dannybackx Exp $
+ * $Id: RepType.c,v 1.21 2002/04/12 23:38:44 amai Exp $
  *
  * Copyright (C) 1995 Free Software Foundation, Inc.
- * Copyright (C) 1995-2001 LessTif Development Team
+ * Copyright (C) 1995-2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,7 +22,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
  **/
-static const char rcsid[] = "$Id: RepType.c,v 1.20 2001/07/27 18:51:57 dannybackx Exp $";
+static const char rcsid[] = "$Id: RepType.c,v 1.21 2002/04/12 23:38:44 amai Exp $";
 
 #include <LTconfig.h>
 
@@ -34,7 +34,7 @@ static const char rcsid[] = "$Id: RepType.c,v 1.20 2001/07/27 18:51:57 dannyback
 #include <Xm/XmP.h>
 #include <Xm/RepType.h>
 
-#include "LTmisc.h"
+#include <XmI/LTmisc.h>
 
 #include <XmI/DebugUtil.h>
 
