@@ -1,8 +1,9 @@
 /**
  *
- * $Id: TearOffB.c,v 1.19 1999/07/02 05:41:57 gritton Exp $
+ * $Id: TearOffB.c,v 1.23 2001/07/27 18:51:57 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
+ * Copyright (C) 1996-2001 LessTif Development Team 
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -22,15 +23,16 @@
  *
  **/
 
-static const char rcsid[] = "$Id: TearOffB.c,v 1.19 1999/07/02 05:41:57 gritton Exp $";
+static const char rcsid[] = "$Id: TearOffB.c,v 1.23 2001/07/27 18:51:57 dannybackx Exp $";
 
 #include <LTconfig.h>
-#include <XmI/XmI.h>
 
+#include <XmI/XmI.h>
 #include <Xm/XmP.h>
 #include <Xm/MenuShell.h>
 #include <Xm/MenuUtilP.h>
 #include <Xm/TearOffBP.h>
+#include <Xm/TearOffP.h>
 #include <Xm/CascadeB.h>
 #include <Xm/CascadeBG.h>
 #include <Xm/DisplayP.h>
@@ -184,7 +186,6 @@ XmTearOffButtonClassRec xmTearOffButtonClassRec = {
        /* translations         */ _XmTearOffB_overrideTranslations,
     },
 };
-/* *INDENT-ON* */
 
 
 WidgetClass xmTearOffButtonWidgetClass = (WidgetClass)&xmTearOffButtonClassRec;
@@ -247,7 +248,7 @@ initialize(Widget request, Widget new_w,
 {
     int trh;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "TOB_initialize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "TOB_initialize\n"));
 
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
 			     TOB_SeparatorType(new_w), new_w))
@@ -285,7 +286,7 @@ set_values(Widget old, Widget request, Widget new_w,
 {
     Boolean refresh_needed = False;
 
-    DEBUGOUT(XdbDebug(__FILE__, new_w, "TOB_SetValues()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "TOB_SetValues()\n"));
 
     if (!XmRepTypeValidValue(XmRepTypeGetId(XmRSeparatorType),
 			     TOB_SeparatorType(new_w), new_w))
@@ -332,7 +333,7 @@ set_values(Widget old, Widget request, Widget new_w,
 static void
 expose(Widget w, XEvent *event, Region region)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "TearOffB expose\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TearOffB expose\n"));
 
     _XmDrawSeparator(XtDisplay(w), XtWindow(w),
 		     Prim_TopShadowGC(w), Prim_BottomShadowGC(w),
@@ -370,7 +371,7 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
     /* Motif does not have this method */
     XtWidgetGeometry a;		/* Standin for answer if NULL parameter */
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "TOB_query_geometry\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "TOB_query_geometry\n"));
 
 #define	Wants(x)	(proposed->request_mode & x)
 
@@ -515,12 +516,12 @@ EventLoop(Widget w, GC gc,
 
     if (!opaque_move)
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Not opaque move\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Not opaque move\n"));
 	DrawOutline(w, gc, xl, yt, Width, Height);
     }
     else
     {
-	DEBUGOUT(XdbDebug(__FILE__, w, "Opaque move\n"));
+	DEBUGOUT(_LtDebug(__FILE__, w, "Opaque move\n"));
     }
 
     while (!finished)
@@ -543,7 +544,7 @@ EventLoop(Widget w, GC gc,
 	    {
 		_XmRecordEvent(&oevent);
 
-		DEBUGOUT(XdbDebug(__FILE__, w, "Discard event\n"));
+		DEBUGOUT(_LtDebug(__FILE__, w, "Discard event\n"));
 
 		if (oevent.type == ButtonRelease)
 		{
@@ -604,7 +605,7 @@ EventLoop(Widget w, GC gc,
 
 	case MotionNotify:
 
-	    DEBUGOUT(XdbDebug(__FILE__, w, "MOTION NOTIFY\n"));
+	    DEBUGOUT(_LtDebug(__FILE__, w, "MOTION NOTIFY\n"));
 
 	    xl = oevent.xmotion.x_root;
 	    yt = oevent.xmotion.y_root;
@@ -680,7 +681,7 @@ BDrag(Widget w, XEvent *event, String *params, Cardinal *num_params)
     unsigned long gcm;
     GC gc;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "BDrag\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "BDrag\n"));
 
     XGetGeometry(XtDisplay(shell), XtWindow(shell),
 		 &root, &dx, &dy, &dw, &dh, &bw, &depth);
@@ -734,7 +735,7 @@ BActivate(Widget w,
     Widget parent, shell;
     Boolean validButton;
 
-    DEBUGOUT(XdbDebug(__FILE__, w, "BActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "BActivate\n"));
 
     parent = XtParent(w);
 
@@ -777,7 +778,7 @@ KActivate(Widget w,
 	  String *params,
 	  Cardinal *num_params)
 {
-    DEBUGOUT(XdbDebug(__FILE__, w, "KActivate\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "KActivate\n"));
 
     _XmTearOffInitiate(w, event);
 }
