@@ -1,9 +1,9 @@
 /**
  *
- * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Text.c,v 1.152 2001/11/26 19:40:24 dannybackx Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Text.c,v 1.168 2003/08/19 09:16:13 dannybackx Exp $
  *
  * Copyright (C) 1997 Free Software Foundation, Inc.
- * Copyright  1997, 1998, 1999, 2000, 2001 LessTif Development Team
+ * Copyright  1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,16 +23,20 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Text.c,v 1.152 2001/11/26 19:40:24 dannybackx Exp $";
+static const char rcsid[] = "$Id: Text.c,v 1.168 2003/08/19 09:16:13 dannybackx Exp $";
 
-#undef VERBOSE
+#define VERBOSE
 
 #include <LTconfig.h>
 
+#include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stddef.h>    /* for  wchar_t */
 #include <limits.h>    /* for INT_MAX */
+#ifdef HAVE_WCHAR_H
+#include <wchar.h>
+#endif
 
 #include <Xm/XmP.h>
 #include <Xm/TextP.h>
@@ -61,47 +65,29 @@ static const char rcsid[] = "$Id: Text.c,v 1.152 2001/11/26 19:40:24 dannybackx
 #include <XmI/DebugUtil.h>
 
 
-#define _XmMin(a,b)  ((a) < (b)) ? (a) : (b)
-#define _XmMax(a,b)  ((a) > (b)) ? (a) : (b)
-
 /* Forward Declarations */
 
 static void ClassInitialize(void);
-
 static void ClassPartInitialize(WidgetClass widget_class);
-
 static void Initialize(Widget request, Widget new_w,
 		       ArgList args, Cardinal *num_args);
-
 static void Destroy(Widget w);
-
 static void Resize(Widget w);
-
 static void Realize(Widget w, XtValueMask *value_mask,
 		    XSetWindowAttributes *attributes);
-
 static void DoExpose(Widget w, XEvent *event, Region region);
-
 static XtGeometryResult query_geometry(Widget w,
 				      XtWidgetGeometry *proposed,
 				      XtWidgetGeometry *answer);
-
 static void _XmTextSetEditable(Widget w, Boolean e);
-
 static Boolean SetValues(Widget current, Widget request, Widget new_w,
 			 ArgList args, Cardinal *num_args);
-
 static void RefigureLines(XmTextWidget w);
-
 static void InitializeLineTable(XmTextWidget w);
-
 static Cardinal GetSecResData(WidgetClass wc,
 			      XmSecondaryResourceData **resdata);
-
 static OutputCreateProc output_create = _XmTextOutputCreate;
-
 static InputCreateProc input_create = _XmTextInputCreate;
-
 void _XmTextInvalidate(XmTextWidget w, XmTextPosition position,
 		       XmTextPosition topos, long delta);
 void _XmTextExportValue(Widget w, int offset, XtArgVal *value);
@@ -180,7 +166,7 @@ static XtResource resources[] =
     {
 	XmNvalue, XmCValue, XmRString,
 	sizeof(String), Offset(value),
-	XmRString, (XtPointer)"" /*NULL*/
+	XmRString, (XtPointer)NULL
     },
     {
 	XmNvalueWcs, XmCValueWcs, XmRValueWcs,
@@ -636,7 +622,7 @@ Initialize(Widget request, Widget new_w,
 	/* FIXME : when/how is char_size more than 1 */
     Text_CharSize(w) = 1;
 
-    if ( Text_VerifyBell(w) == XmUNSPECIFIED )
+    if ( Text_VerifyBell(w) == (Boolean)XmUNSPECIFIED )
 	{
 	Widget vendor = XtParent(w);
 	while ( vendor && !XmIsVendorShell( vendor ) )
@@ -644,20 +630,16 @@ Initialize(Widget request, Widget new_w,
 	if ( vendor )
 	    Text_VerifyBell(w) = _XmGetAudibleWarning(vendor);
 	}
-    if ( strlen ( Text_Value(w) ) != 0 || passedSourceAsArg )
+
+    if ( (Text_Value(w) && strlen(Text_Value(w))> 0) || passedSourceAsArg )
 	{
 	_XmTextUpdateLineTable( (Widget)w, 0, strlen( Text_Value(w) ),
 		       NULL, True /* it is unused */ );
 	Text_BottomPos(w) = Text_LineTable(w)[Text_LineCount(w)].start_pos;
 	Text_Repaint(w).range[0].to = Text_BottomPos(w);
-
-	/*CP: but the value attribute is a hangover of M*tif 1.1
-		and seems to be unused in 1.2. SO free it. */
-	if (strlen(Text_Value(w)) == 0)
-		XtFree ( (char*) Text_Value(w) );
-
-	Text_Value(w) = NULL;
 	}
+     Text_Value(w) = NULL; /* amai: FIX ME! We should check for value! */
+     Text_WcsValue(w) = NULL; /* amai: FIX ME! We should check for value! */
 
     /* initialize default DropSite */
     import_target[0] = XmInternAtom(XtDisplay(new_w), _XA_COMPOUND_TEXT, False);
@@ -731,24 +713,41 @@ SetValues(Widget old, Widget request, Widget new_w,
 
     Text_InSetValues(nw) = True;
 
-    if (Text_Value(nw) != Text_Value(ow))
-    {
-	XmTextSetString(new_w, Text_Value(new_w));
+	if (nw->core.sensitive != ow->core.sensitive) {
+		OutputData o = Text_OutputData(new_w);
+		XGCValues	v;
+		int		m;
 
-	refresh_needed = True;
-    }
+		if (! nw->core.sensitive) {
+			m = GCFillStyle | GCStipple;
+			v.fill_style = FillStippled;
+			v.stipple = XmGetPixmapByDepth(XtScreen(new_w), "50_foreground", 1, 0, 1);
+		} else {
+			m = GCFillStyle;
+			v.fill_style = FillSolid;
+		}
 
-    if (Text_WcsValue(nw) != Text_WcsValue(ow))
+		if (XtIsRealized(new_w))
+			XChangeGC(XtDisplay(new_w), Out_DrawGC(o), m, &v);
+		refresh_needed = True;
+	}
+
+    if (Text_WcsValue(nw))
     {
 	XmTextSetStringWcs(new_w, Text_WcsValue(new_w));
-
+	Text_WcsValue(nw) = NULL;
+	refresh_needed = True;
+    } else if (Text_Value(nw))
+    {
+	XmTextSetString(new_w, Text_Value(new_w));
+	Text_Value(nw) = NULL;
 	refresh_needed = True;
     }
 
+
     if (Text_Editable(nw) != Text_Editable(ow))
     {
 	_XmTextSetEditable(new_w, Text_Editable(nw));
-
 	refresh_needed = True;
     }
 
@@ -984,8 +983,6 @@ query_geometry(Widget w, XtWidgetGeometry *proposed, XtWidgetGeometry *answer)
 #endif
 }
 
-
-
 /* Drawing Routines ------------------------------------------------------- */
 static void
 Redisplay(XmTextWidget w)
@@ -1023,7 +1020,6 @@ Redisplay(XmTextWidget w)
     Text_InRedisplay(w) = False;
 }
 
-
 static Cardinal
 GetSecResData(WidgetClass wc, XmSecondaryResourceData **resdata)
 {
@@ -1055,7 +1051,6 @@ LineIncrease(XmTextWidget w, LineNum num)
     }
 }
 
-
 /*
  * Set up the entire line table, starting with the first visible position.
  *
@@ -1105,7 +1100,7 @@ RefigureLines(XmTextWidget w)
 				   Text_LineTable(w)[i].start_pos != 0);
 	 i++)
     {
-	DEBUGOUT(_LtDebug(__FILE__, w,
+	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "RefigureLines: [%d] start_pos %d virt %d\n",
 			  i, Text_LineTable(w)[i].start_pos,
 			  Text_LineTable(w)[i].virt_line));
@@ -1219,7 +1214,7 @@ RefigureLines(XmTextWidget w)
 	}
     }
 
-#if VERBOSE
+#ifdef VERBOSE
     DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "RefigureLines: top on line %d, bottompos %d\n",
 		      i, Text_BottomPos(w)));
@@ -1227,34 +1222,6 @@ RefigureLines(XmTextWidget w)
 #endif
 }
 
-
-#if 0
-/* This is not used anywhere. Remove ? FIX ME */
-static LineNum
-LineTableFindNum(XmTextWidget w, XmTextPosition pos)
-{
-    LineNum i;
-
-    if (pos < Text_TopPos(w))
-    {
-	return NOLINE;
-    }
-
-    for (i = 0; i < Text_LineCount(w); i++)
-    {
-	Line line = &Text_Line(w)[i];
-	Line next = &Text_Line(w)[i + 1];
-
-	if (pos >= line->start && pos < next->start)
-	{
-	    return i;
-	}
-    }
-
-    return NOLINE;
-}
-#endif
-
 /* Line-table functions (for the whole textstring)------------------------ */
 
 /* Running test/Xm/test6 (be sure to give it focus so something interesting
@@ -1288,11 +1255,12 @@ _XmTextUpdateLineTable(Widget w,
 		       XmTextBlock block,
 		       Boolean update)
 {
-    XmTextWidget tw = (XmTextWidget)w;
-    XmTextPosition next, ostart;
-    XmTextLineTable line;
-    unsigned int index;
-    Boolean wrap = _XmTextShouldWordWrap(tw), next_is_virtual;
+	Cardinal	i;
+	XmTextWidget	tw = (XmTextWidget)w;
+	XmTextPosition	next, ostart;
+	XmTextLineTable line;
+	unsigned int	index;
+	Boolean		wrap = _XmTextShouldWordWrap(tw), next_is_virtual;
 
     DEBUGOUT(_LtDebug(__FILE__, w, "_XmTextUpdateLineTable start %d end %d\n",
     		start, end));
@@ -1405,7 +1373,7 @@ _XmTextUpdateLineTable(Widget w,
 	{
 	    if (index >= Text_TableSize(w))
 	    {
-		Cardinal i = Text_TableSize(w);
+		i = Text_TableSize(w);
 
 		Text_TableSize(w) += LINETABLE_INCREMENT;
 		Text_LineTable(w) = (XmTextLineTable)
@@ -1487,6 +1455,10 @@ _XmTextUpdateLineTable(Widget w,
 	    line->start_pos = start;
 	    line->virt_line = False;
 
+	    DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
+		       "_XmTextUpdateLineTable nowrap : line %d start %d virtual %d\n",
+				      index, line->start_pos, line->virt_line));
+
 	    /* Be careful not to do PASTENDPOS + 1 */
 	    start = (*Text_Source(w)->Scan) (Text_Source(w), start,
 					  XmSELECT_LINE, XmsdRight, 1, False);
@@ -1508,9 +1480,12 @@ _XmTextUpdateLineTable(Widget w,
      * All done. Store some stuff in the widget.
      */
     Text_TotalLines(w) = index;
+    for (i=index; i<Text_TableSize(w); i++) {
+	Text_LineTable(w)[i].start_pos = 0;
+	Text_LineTable(w)[i].virt_line = False;
+    }
 }
 
-
 /*
  * This function is the *initialize* variant of the one above.
  */
@@ -1538,7 +1513,6 @@ InitializeLineTable(XmTextWidget w)
 /* Not needed beyond this */
 #undef LINETABLE_INCREMENT
 
-
 extern unsigned int
 _XmTextGetTableIndex(XmTextWidget w, XmTextPosition pos)
 {
@@ -1557,7 +1531,7 @@ _XmTextGetTableIndex(XmTextWidget w, XmTextPosition pos)
 
     for (; current->start_pos > pos; current--, i--);
 
-#if VERBOSE
+#ifdef VERBOSE
     DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 		      "XmTextGetTableIndex Pos %d Index %d\n", pos, i));
 #endif
@@ -1565,7 +1539,6 @@ _XmTextGetTableIndex(XmTextWidget w, XmTextPosition pos)
     return i;
 }
 
-
 /* Quasi-Public Functions ------------------------------------------------ */
 extern void
 _XmTextLineInfo(XmTextWidget w, LineNum line,
@@ -1575,14 +1548,12 @@ _XmTextLineInfo(XmTextWidget w, LineNum line,
     *extra = Text_Line(w)[line].extra;
 }
 
-
 extern void
 _XmTextMarkRedraw(XmTextWidget w, XmTextPosition left,
 		  XmTextPosition right)
 {
 }
 
-
 extern LineNum
 _XmTextPosToLine(XmTextWidget w, XmTextPosition position)
 {
@@ -1683,7 +1654,7 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 
     if (cbs.doit)
     {
-#if VERBOSE
+#ifdef VERBOSE
 	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "Text_CursorPos before draw: %08x\n",
 			  Text_CursorPos(w)));
@@ -1700,7 +1671,7 @@ _XmTextSetCursorPosition(Widget w, XmTextPosition position)
 	Text_CursorPos(w) = position;
 #endif
 
-#if VERBOSE
+#ifdef VERBOSE
 	DEBUGOUT(_LtDebug(__FILE__, (Widget)w,
 			  "Text_CursorPos after draw: %08x\n",
 			  Text_CursorPos(w)));
@@ -2309,19 +2280,23 @@ XmTextGetSubstring(Widget w, XmTextPosition start, int num_chars,
 	return XmCOPY_FAILED;
     }
 
-    if (num_chars < buffer_size)
+    len = (*Text_Source(w)->ReadSource)
+	    (Text_Source(w), start, start+num_chars, &block) - start;
+
+    if(len < num_chars)
     {
-	len = num_chars;
+	retval = XmCOPY_TRUNCATED;
+    } /* no else: retval may be updated to XmCOPY_FAILED in next test */
+
+    if(len > buffer_size)
+    {
+	retval = XmCOPY_FAILED;
     }
     else
     {
-	len = buffer_size - 1;
-	retval = XmCOPY_TRUNCATED;
+    	memcpy(buffer, block.ptr, len);
     }
 
-    (*Text_Source(w)->ReadSource) (Text_Source(w), start, start+len, &block);
-
-    memcpy(buffer, block.ptr, len);
     XtFree(block.ptr);
 
     return retval;
@@ -2592,19 +2567,15 @@ XmTextReplaceWcs(Widget w, XmTextPosition from_pos, XmTextPosition to_pos,
 extern void
 XmTextSetAddMode(Widget w, Boolean state)
 {
-    if (XtIsSubclass(w, xmTextWidgetClass))
-    {
-	_XmWarning(w, "XmTextSetAddMode: not implemented");
-	;			/* FIX ME */
-    }
-    else if (XtIsSubclass(w, xmTextFieldWidgetClass))
-    {
-	XmTextFieldSetAddMode(w, state);
-    }
-    else
-    {
-	_XmWarning(w, "XmTextSetAddMode: widget has invalid class");
-    }
+	XmTextWidget tw = (XmTextWidget)w;
+
+	if (XtIsSubclass(w, xmTextWidgetClass)) {
+		Text_AddMode(w) = state;
+	} else if (XtIsSubclass(w, xmTextFieldWidgetClass)) {
+		XmTextFieldSetAddMode(w, state);
+	} else {
+		_XmWarning(w, "XmTextSetAddMode: widget has invalid class");
+	}
 }
 
 
@@ -3003,10 +2974,14 @@ XmTextScroll(Widget aw, int n)
     }
     else
     {
+	/* bug #672292 */
+	index = _XmMin(n + top_index, Text_TotalLines(w)-1);
+#if 0
 	index = _XmMin(n + top_index,
 /* SG (15/08/1998)  Text_TotalLines(w) - 1) - Text_LineCount(w) + 1;
    we would rather like to be able to scroll down to the last line */
 		       Text_TotalLines(w) ) - Text_LineCount(w) + 1;
+#endif
     }
     DEBUGOUT(_LtDebug(__FILE__, aw, "XmTextScroll index=%d n=%d\n", index, n));
 
