@@ -1,9 +1,9 @@
 /**
  *
- * $Id: Vendor.c,v 1.82 2001/09/13 12:28:20 amai Exp $
+ * $Header: /cvsroot/lesstif/lesstif/lib/Xm/Vendor.c,v 1.99 2003/08/12 16:33:20 dannybackx Exp $
  *
  * Copyright (C) 1996 Free Software Foundation, Inc.
- * Copyright (C) 1996, 1997, 1998, 1999, 2000, 2001 LessTif Development Team
+ * Copyright  1996, 1997, 1998, 1999, 2000, 2001, 2002 LessTif Development Team
  *
  * This file is part of the GNU LessTif Library.
  *
@@ -23,7 +23,7 @@
  *
  **/
 
-static const char rcsid[] = "$Id: Vendor.c,v 1.82 2001/09/13 12:28:20 amai Exp $";
+static const char rcsid[] = "$Id: Vendor.c,v 1.99 2003/08/12 16:33:20 dannybackx Exp $";
 
 #include <LTconfig.h>
 
@@ -77,10 +77,9 @@ extern void _LtXmFixupVendorShell(void);
 unsigned long _DLL_InitTerm(unsigned long mod_handle, unsigned long flag);
 #endif
 
-/* We use a 'private', i.e. non-declared but actually
-   exported call from OpenGroup's Intrinsic sources
-   (lib/Xt/Callback.c) here.
-   Note that we don't give the precise prototype:
+/* We use a 'private', i.e. non-declared, but actually exported call
+    from the original Intrinsic sources (lib/Xt/Callback.c) here.
+    Note that we don't give the precise prototype:
  */
 extern void 
 _XtRemoveCallback (
@@ -147,6 +146,7 @@ static void LTShellPopupCallback(Widget w,
 static void LTShellPopdownCallback(Widget w,
 				   XtPointer ClientData,
 				   XtPointer CallbackData);
+static void LTGrabRelatives(XmVendorShellExtObject grabber);
 static void VendorFromHorizontalPixels(Widget w, int offset, XtArgVal *value);
 static void VendorFromVerticalPixels(Widget w, int offset, XtArgVal *value);
 static XmImportOperator VendorToHorizontalPixels(Widget w, int offset,
@@ -924,6 +924,8 @@ secondary_object_create(Widget req, Widget new_w,
 
     bce = _XmGetBaseClassExtPtr(XtClass(new_w), XmQmotif);
 
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "secondary_object_create\n"));
+
     /*
      * The shell extension objects have their XmNdesktopParent set pointing
      * to the next higher level within the shells' hierarchy. The other
@@ -976,6 +978,8 @@ secondary_object_create(Widget req, Widget new_w,
     /*
      * Now install some callbacks for use with the grab mechanism...
      */
+    DEBUGOUT(_LtDebug2(__FILE__, new_w, ed->widget, "Install pop up/down callbacks\n"));
+
     XtAddCallback(new_w, XmNpopupCallback,
 		  LTShellPopupCallback, (XtPointer)ed->widget);
     XtAddCallback(new_w, XmNpopdownCallback,
@@ -1035,8 +1039,7 @@ initialize(Widget req, Widget new_w,
     XtEventHandler str_not;
     XmShellExtClassRec *shellc;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
-		      "####VendorShell %s initialize\n", XtName(new_w)));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "####VendorShell initialize\n"));
 
     ((WMShellWidget)new_w)->wm.wait_for_wm = True;
 
@@ -1096,7 +1099,7 @@ destroy(Widget w)
     XmWidgetExtData data;
 
     DEBUGOUT(_LtDebug(__FILE__, w, "VendorShell Destroy()\n"));
-    DEBUGOUT(_LtDebug("NEDIT", w, "VendorShell Destroy()\n"));
+//  DEBUGOUT(_LtDebug("NEDIT", w, "VendorShell Destroy()\n"));
 
     _XmPopWidgetExtData(w, &data, XmSHELL_EXTENSION);
     if (data != NULL) {
@@ -1155,11 +1158,9 @@ _XmVendorExtDestroy(Widget w)
 
 
 static void
-realize(Widget w,
-	XtValueMask *value_mask,
-	XSetWindowAttributes *attributes)
+realize(Widget w, XtValueMask *value_mask, XSetWindowAttributes *attributes)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "Realize\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "VendorRealize\n"));
 
     if (XtWidth(w) == 0)
     	XtWidth(w) = 1;
@@ -1222,15 +1223,7 @@ WmProtocolHandler(Widget w, XtPointer client, XtPointer call)
 	break;
 
     case XmUNMAP:
-	/* The word says UNMAP but we really have to unMANAGE */
-	for (i = 0; i < MGR_NumChildren(w); i++)
-	    if (XtIsManaged(MGR_Children(w)[i]))
-	    {
-		DEBUGOUT(_LtDebug2(__FILE__, w, MGR_Children(w)[i],
-				   "XtUnmanageChild(child)\n"));
-		XtUnmanageChild(MGR_Children(w)[i]);
-		return;		/* Shells have only one managed child */
-	    }
+	XtPopdown(w);
 	break;
 
     case XmDO_NOTHING:
@@ -1320,44 +1313,51 @@ set_values_posthook(Widget old, Widget req, Widget new_w,
     return False;
 }
 
-
 static Boolean
-set_values(Widget old, Widget req, Widget new_w,
-	   ArgList args, Cardinal *num_args)
+set_values(Widget old, Widget req, Widget new_w, ArgList args, Cardinal *num_args)
 {
-    XmWidgetExtData data;
-    Boolean refresh = False;
+	XmWidgetExtData		data;
+	Boolean			refresh = False;
+	XmVendorShellExtObject	ve;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
-		      "%s:set_values(%d): %i args\n"
-		      "\t    old X %5i Y %5i W %5i H %5i\n"
-		      "\trequest X %5i Y %5i W %5i H %5i\n"
-		      "\t  new_w X %5i Y %5i W %5i H %5i\n",
-		      __FILE__, __LINE__,
-		      *num_args,
-		      XtX(old), XtY(old),
-		      XtWidth(old), XtHeight(old),
-		      XtX(req), XtY(req),
-		      XtWidth(req), XtHeight(req),
-		      XtX(new_w), XtY(new_w),
-		      XtWidth(new_w), XtHeight(new_w)));
-    DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
+	DEBUGOUT(_LtDebug(__FILE__, new_w,
+		"VendorSetValues: %i args\n"
+		"\t    old X %5i Y %5i W %5i H %5i\n"
+		"\trequest X %5i Y %5i W %5i H %5i\n"
+		"\t  new_w X %5i Y %5i W %5i H %5i\n",
+		*num_args,
+		XtX(old), XtY(old),
+		XtWidth(old), XtHeight(old),
+		XtX(req), XtY(req),
+		XtWidth(req), XtHeight(req),
+		XtX(new_w), XtY(new_w),
+		XtWidth(new_w), XtHeight(new_w)));
+	DEBUGOUT(_LtDebugPrintArgList(__FILE__, new_w, args, *num_args, False));
 
-    data = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION);
-    if (data)
-    {
-	refresh = _XmVendorExtSetValues(data->oldWidget, data->reqWidget,
+	data = _XmGetWidgetExtData(new_w, XmSHELL_EXTENSION);
+	if (data) {
+		refresh = _XmVendorExtSetValues(data->oldWidget, data->reqWidget,
 					data->widget, args, num_args);
-    }
+	}
 
-    return refresh;
+	return refresh;
 }
 
+extern void
+_LtVendorUnmap(Widget child)
+{
+	XmWidgetExtData data = _XmGetWidgetExtData(XtParent(child), XmSHELL_EXTENSION);
+	XmVendorShellExtObject ve;
+
+	DEBUGOUT(_LtDebug2(__FILE__, XtParent(child), child, "_LtVendorUnmap\n"));
+	if (data) {
+		ve = (XmVendorShellExtObject)data->widget;
+		LTRemoveGrab(NULL, ve, True);
+	}
+}
 
 static void
-get_values_prehook(Widget widget,
-		   ArgList args,
-		   Cardinal *num_args)
+get_values_prehook(Widget widget, ArgList args, Cardinal *num_args)
 {
     XmBaseClassExt *bce;
     XmWidgetExtData data;
@@ -1389,26 +1389,21 @@ get_values_prehook(Widget widget,
 
 
 static void
-get_values_posthook(Widget widget,
-		    ArgList args,
-		    Cardinal *num_args)
+get_values_posthook(Widget widget, ArgList args, Cardinal *num_args)
 {
-    XmWidgetExtData ext;
+	XmWidgetExtData ext;
 
-    _XmPopWidgetExtData(widget, &ext, XmSHELL_EXTENSION);
-
-    _XmExtObjFree((XtPointer)ext->widget);
-
-    XtFree((char *)ext);
+	_XmPopWidgetExtData(widget, &ext, XmSHELL_EXTENSION);
+	_XmExtObjFree((XtPointer)ext->widget);
+	XtFree((char *)ext);
 }
 
-
 static void
 change_managed(Widget wid)
 {
     int i;
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "change_managed()\n"));
+    DEBUGOUT(_LtDebug(__FILE__, wid, "VendorChangeManaged()\n"));
 #define superclass (&wmShellClassRec)
     (*superclass->composite_class.change_managed) (wid);
 #undef superclass
@@ -1423,19 +1418,17 @@ change_managed(Widget wid)
     }
 }
 
-
 static void
 insert_child(Widget w)
 {
-    DEBUGOUT(_LtDebug(__FILE__, w, "insert_child()\n"));
-    /* Keep those pesky objects OUT of the child list */
-    if (!XtIsRectObj(w))
-    {
-	return;
-    }
+	DEBUGOUT(_LtDebug(__FILE__, w, "insert_child()\n"));
+	/* Keep those pesky objects OUT of the child list */
+	if (!XtIsRectObj(w)) {
+		return;
+	}
 
 #define superclass (&wmShellClassRec)
-    (*superclass->composite_class.insert_child) (w);
+	(*superclass->composite_class.insert_child) (w);
 #undef superclass
 }
 
@@ -1470,6 +1463,11 @@ _XmFilterResources(XtResource *resources,
 }
 
 
+/*
+ * This dumps LessTif's idea about Xt's grab list.
+ * Changed so it gets triggered both by selecting this file and by GRAB,
+ * but not twice :-)
+ */
 static void
 dump_grab_list(Widget w)
 {
@@ -1480,7 +1478,18 @@ dump_grab_list(Widget w)
 	DEBUGOUT(_LtDebug(__FILE__, w, "Current Grab List\n"));
 	for (i = 0; i < Display_NumModals(w); i++)
 	{
-	    DEBUGOUT(_LtDebug(__FILE__, w, " Wid: %p (%s) ve: %p grabber: %p exclusive: %d sprung: %d\n",
+	    DEBUGOUT(_LtDebug0(__FILE__, w, "\tWid: %p (%s) ve: %p grabber: %p exclusive: %d sprung: %d\n",
+		   Display_Modals(w)[i].wid,
+		   XtName(Display_Modals(w)[i].wid),
+		   Display_Modals(w)[i].ve,
+		   Display_Modals(w)[i].grabber, Display_Modals(w)[i].exclusive,
+		   Display_Modals(w)[i].springLoaded));
+	}
+    } else if (_LtDebugInDebug("GRAB", w)) {
+	DEBUGOUT(_LtDebug("GRAB", w, "Current Grab List\n"));
+	for (i = 0; i < Display_NumModals(w); i++)
+	{
+	    DEBUGOUT(_LtDebug0("GRAB", w, "\tWid: %p (%s) ve: %p grabber: %p exclusive: %d sprung: %d\n",
 		   Display_Modals(w)[i].wid,
 		   XtName(Display_Modals(w)[i].wid),
 		   Display_Modals(w)[i].ve,
@@ -1505,74 +1514,100 @@ static void
 LTAddGrab(Widget wid, Boolean exclusive, Boolean spring_loaded,
 	  XmVendorShellExtObject ve, XmVendorShellExtObject grabber)
 {
-    Widget d;
-    XmModalData modal;
+	Widget d;
+	XmModalData	modal = NULL, ps;
+	int i;
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab\n"));
-    /*
-     * If there's no widget wid specified, we'll take the logical parent
-     * of the vendor shell extension object as the grab destination instead.
-     */
-    if (wid == NULL)
-    {
-	wid = ExtObj_LogicalParent(ve);
-    }
-
-    d = XmGetXmDisplay(XtDisplayOfObject(wid));
-    {
-    int i;
-    XmModalData ps = Display_Modals(d);
-
-	for (i = Display_NumModals(d); i > 0; i--, ps++)
-	{
-	    if (ps->wid == wid)
-	    {
-		return;
-	    }
+	/*
+	 * If there's no widget wid specified, we'll take the logical parent
+	 * of the vendor shell extension object as the grab destination instead.
+	 */
+	if (wid == NULL) {
+		wid = ExtObj_LogicalParent(ve);
+		DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab(NULL)\n"));
+	} else {
+		DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab\n"));
 	}
-    }
-    dump_grab_list(d);
 
-    /* grow the modal list, if necessary */
-    if (Display_NumModals(d) >= Display_MaxModals(d))
-    {
-	Display_MaxModals(d) += 8;
-	Display_Modals(d) = (XmModalData)XtRealloc((char *)Display_Modals(d),
-						   sizeof(XmModalDataRec) *
-						   Display_MaxModals(d));
-    }
+	d = XmGetXmDisplay(XtDisplayOfObject(wid));
+	ps = Display_Modals(d);
 
-    /*
-     * Now occupy a free entry and pollute it with information about the
-     * grab. Then introduce the grab to the Intrinsics and make sure the
-     * grab gets removed if the grab widget should ever be destroyed
-     * before releasing the grab. This is necessary so LessTif's grab list
-     * stays in sync with the Intrinsics's list.
-     */
-    modal = Display_Modals(d) + Display_NumModals(d);
-    modal->wid = wid;
-    modal->ve = ve;
-    modal->grabber = grabber;
-    modal->exclusive = exclusive;
-    modal->springLoaded = spring_loaded;
+#if 0
+	/* Xt doesn't check what's in there already so why should we ? */
+	for (i = Display_NumModals(d); i > 0; i--, ps++) {
+#if 1
+		/*
+		 * This possibly fixes the nedit menu problem.
+		 * Now we're comparing not only the widget but also its
+		 * status. This probably matches Xt's algorithm better.
+		 */
+		if (ps->wid == wid && ps->exclusive == exclusive) {
+			DEBUGOUT(_LtDebug(__FILE__, wid,
+				"LTAddGrab(double) [%d %d] old [%d %d]\n",
+				ps->exclusive, ps->springLoaded,
+				exclusive, spring_loaded));
+			modal = ps;
+		}
+#else
+		if (ps->wid == wid) {
+			DEBUGOUT(_LtDebug(__FILE__, wid,
+				"LTAddGrab(double) [%d %d] old [%d %d]\n",
+				ps->exclusive, ps->springLoaded,
+				exclusive, spring_loaded));
+			/*
+			 * FIX ME this tests for a known problem, it may be
+			 * necessary to handle more cases.
+			 */
+			if (exclusive == ps->exclusive)
+				return;
+			modal = ps;
+		}
+#endif
+	}
+#endif
+	dump_grab_list(d);
 
-    Display_NumModals(d)++;
+	if (modal == 0) {
+		/* grow the modal list, if necessary */
+		if (Display_NumModals(d) >= Display_MaxModals(d)) {
+			Display_MaxModals(d) += 8;
+			Display_Modals(d) = (XmModalData)XtRealloc(
+				(char *)Display_Modals(d),
+				sizeof(XmModalDataRec) * Display_MaxModals(d));
+		}
+		modal = Display_Modals(d) + Display_NumModals(d);
+		Display_NumModals(d)++;
+	}
 
-    DEBUGOUT(_LtDebug("GRAB", wid, "%s:XtAddGrab(%d) - %s %s\n", 
-    	__FILE__, __LINE__,
-    	exclusive ? "True" : "False",
-    	spring_loaded ? "True" : "False"));
-    XtAddGrab(wid, exclusive, spring_loaded);
+	/*
+	 * Now occupy a free entry and pollute it with information about the
+	 * grab. Then introduce the grab to the Intrinsics and make sure the
+	 * grab gets removed if the grab widget should ever be destroyed
+	 * before releasing the grab. This is necessary so LessTif's grab list
+	 * stays in sync with the Intrinsics's list.
+	 */
+	modal->wid = wid;
+	modal->ve = ve;
+	modal->grabber = grabber;
+	modal->exclusive = exclusive;
+	modal->springLoaded = spring_loaded;
 
-    /*
-     * Never, NEVER, add this callback before you'd set up the grab. See
-     * below ( RemoveLessTifGrab() ) for some explanation.
-     */
-    XtAddCallback(wid, XmNdestroyCallback,
-		  (XtCallbackProc)LTRemoveGrabCallback,
-		  (XtPointer)ve);
-    DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab - After it is added\n"));
-    dump_grab_list(d);
+	DEBUGOUT(_LtDebug("GRAB", wid, "%s:XtAddGrab(%d) - %s %s\n", 
+		__FILE__, __LINE__,
+		exclusive ? "True" : "False",
+		spring_loaded ? "True" : "False"));
+	XtAddGrab(wid, exclusive, spring_loaded);
+
+	/*
+	 * Never, NEVER, add this callback before you'd set up the grab. See
+	 * below ( RemoveLessTifGrab() ) for some explanation.
+	 */
+	XtAddCallback(wid, XmNdestroyCallback,
+		(XtCallbackProc)LTRemoveGrabCallback,
+		(XtPointer)ve);
+	DEBUGOUT(_LtDebug(__FILE__, wid, "LTAddGrab - After it is added\n"));
+	DEBUGOUT(_LtDebug("GRAB", wid, "LTAddGrab - After it is added\n"));
+	dump_grab_list(d);
 }
 
 
@@ -1621,10 +1656,13 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
     XmModalData pd, ps;
     int i, skipped;
 
-    DEBUGOUT(_LtDebug(__FILE__, wid, "LTRemoveGrab\n"));
-    if (wid == NULL)
-    {
+    if (wid == NULL) {
 	wid = ExtObj_LogicalParent(ve);
+	DEBUGOUT(_LtDebug2(__FILE__, wid, (Widget)ve, "LTRemoveGrab\n"));
+	DEBUGOUT(_LtDebug2("GRAB", wid, (Widget)ve, "LTRemoveGrab\n"));
+    } else {
+	DEBUGOUT(_LtDebug(__FILE__, wid, "LTRemoveGrab\n"));
+	DEBUGOUT(_LtDebug("GRAB", wid, "LTRemoveGrab\n"));
     }
 
     /*
@@ -1653,6 +1691,8 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 
     for (i = Display_NumModals(d); i > 0; i--, ps++)
     {
+//	DEBUGOUT(_LtDebug2("GRAB", XtParent(wid), wid, "NEDIT\n"));
+
 /* amai: The famous "NEdit freeze" bug (an out of sync problem between
          the Xt and LT grab list) was cured by changing
            if ((ps->wid == wid) && !CoreBeingDestroyed(wid) && remove_grab_physically)
@@ -1662,18 +1702,26 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	This 'fix' in turn triggered XtRemoveGrabs with bogus arguments, leading
 	to Xt warning messages. See comments at beginning of LTRemoveGrab()!
 */
+#if 1
+	if ((ps->wid == wid) && remove_grab_physically) {
+		DEBUGOUT(_LtDebug("GRAB", wid, "XtRemoveGrab-1\n"));
+		XtRemoveGrab(wid);
+	} else
+#endif
+#if 1
+	/* 1.83 version */
 	if ((XtParent(wid) == NULL) ||
-	    ((ps->wid == wid) && !CoreBeingDestroyed(wid) &&
-	     !XtIsTopLevelShell(wid) && remove_grab_physically))
-	{
-	    DEBUGOUT(_LtDebug2("GRAB", XtParent(wid), wid, "%s:XtRemoveGrab(%d) - %s %s\n",
-	                       __FILE__, __LINE__,
-			       XtIsShell(wid) ? "True" : "False",
-                               CoreBeingDestroyed(wid) ? "True" : "False"));
-	    XtRemoveGrab(wid);
+			((ps->wid == wid) && !CoreBeingDestroyed(wid) &&
+			!XtIsTopLevelShell(wid) && remove_grab_physically)) {
+		DEBUGOUT(_LtDebug("GRAB", wid, "XtRemoveGrab-2\n"));
+		XtRemoveGrab(wid);
 	}
+#endif
     }
 
+    DEBUGOUT(_LtDebug("GRAB", wid, "Loop to restore grabs : %d iterations\n",
+	Display_NumModals(d)));
+
     ps = pd;
     for (i = Display_NumModals(d); i > 0; i--, ps++, pd++)
     {
@@ -1681,6 +1729,8 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	{
 	    if (ps->wid == wid)
 	    {
+		DEBUGOUT(_LtDebug0("GRAB", wid, "\t%d : %s (skip, equal)\n",
+			i, ps->wid ? XtName(ps->wid) : "(null)"));
 		ps++;
 		i--;
 		skipped++;	/* skip this entry */
@@ -1688,6 +1738,8 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	    else if ((ps->grabber == ve) && ve)
 	    {
 
+		DEBUGOUT(_LtDebug0("GRAB", wid, "\t%d : %s (skip, primary appl modal)\n",
+			i, ps->wid ? XtName(ps->wid) : "(null)"));
 		/* Get rid off all primary application modal grabs too. */
 		ps++;
 		i--;
@@ -1696,6 +1748,8 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	    /* nothing more to skip at the moment */
 	    else
 	    {
+		DEBUGOUT(_LtDebug0("GRAB", wid, "\t%d : %s\n",
+			i, ps->wid ? XtName(ps->wid) : "(null)"));
 		break;
 	    }
 
@@ -1710,6 +1764,7 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
 	 */
 	if (i <= 0)
 	{
+	    DEBUGOUT(_LtDebug0("GRAB", wid, "\tLeave loop\n"));
 	    break;
 	}
 
@@ -1725,6 +1780,8 @@ LTRemoveGrab(Widget wid, XmVendorShellExtObject ve,
     }
 
     Display_NumModals(d) -= skipped;
+    DEBUGOUT(_LtDebug("GRAB", wid, "End of loop to restore grabs : %d modals left\n",
+	Display_NumModals(d)));
 }
 
 
@@ -1742,7 +1799,7 @@ LTRemoveGrabCallback(Widget wid, XtPointer client_data,
 {
     DEBUGOUT(_LtDebug(__FILE__, wid, "LTRemoveGrabCallback()\n"));
     DEBUGOUT(_LtDebug("GRAB", wid, "LTRemoveGrabCallback()\n"));
-#if 0
+
     /* rws 14 Feb 1998
        This is the cause of the segfault in ddd when pressing OK from
        the edit->preferences dialog.  When the "init_shell" is created,
@@ -1757,6 +1814,7 @@ LTRemoveGrabCallback(Widget wid, XtPointer client_data,
        LTAddGrab.  That being the case it should be safe to remove the
        grab!!!
      */
+#if 0
     if (!XtIsSubclass(wid, vendorShellWidgetClass))
 #endif
     {
@@ -1941,7 +1999,8 @@ LTShellPopupCallback(Widget w, XtPointer ClientData, XtPointer CallbackData)
     XtGrabKind GrabKind = XtGrabNone;
     Boolean GrabRelatives = False;
 
-    DEBUGOUT(_LtDebug(__FILE__, w, "ShellPopup callback\n"));
+    DEBUGOUT(_LtDebug(__FILE__, w, "LTShellPopupCallback(%s)\n",
+	_LtDebugMwmInput2String(VSEP_MwmHints(ve).input_mode)));
 
     ws = XmGetXmScreen(XtScreenOfObject(w));
 
@@ -3082,8 +3141,7 @@ _XmVendorExtInitialize(Widget req,
     XmVendorShellExtObject ve = (XmVendorShellExtObject)new_w;
     Atom wm_delete_window;
 
-    DEBUGOUT(_LtDebug(__FILE__, new_w,
-		      "VendorShellExt %s initialize\n", XtName(new_w)));
+    DEBUGOUT(_LtDebug(__FILE__, new_w, "VendorShellExtInitialize\n"));
 
     if (VSEP_DefaultFontList(ve) != NULL)
     {
@@ -3182,16 +3240,16 @@ _XmVendorExtInitialize(Widget req,
 			 VSEPC_DeleteWindowHandler(new_w), (XtPointer)new_w);
 }
 
-
 static Boolean
-_XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
-		      ArgList args, Cardinal *nargs)
+_XmVendorExtSetValues(Widget cw, Widget rw, Widget nw, ArgList args, Cardinal *nargs)
 {
     Atom at;
     long prop32[5];
+    XmVendorShellExtObject o= (XmVendorShellExtObject)nw;
 
     DEBUGOUT(_LtDebug(__FILE__, nw,
-		      "VendorShellExt %s SetValues\n", XtName(nw)));
+		      "VendorShellExtSetValues, args:%d\n",
+		      *nargs));
 
     if (VSEP_ButtonFontList(nw) != VSEP_ButtonFontList(cw))
     {
@@ -3274,7 +3332,46 @@ _XmVendorExtSetValues(Widget cw, Widget rw, Widget nw,
 	}
     }
 
-    return False;
+	/* This really appears to belong in set_values() for the ext object */
+	/* Well, here it is. */
+	if (VSEP_MwmHints(nw).input_mode != VSEP_MwmHints(cw).input_mode)
+	{
+		XtGrabKind GrabKind = XtGrabNone;
+		Boolean GrabRelatives = False;
+
+		switch (VSEP_MwmHints(nw).input_mode) {
+		case MWM_INPUT_PRIMARY_APPLICATION_MODAL:
+			GrabKind = XtGrabExclusive;
+#if 1
+			/* Maybe we can get away with always doing this */
+			GrabRelatives = True;
+#else
+			if (Screen_MwmPresent(ws)) {
+				GrabRelatives = True;
+			}
+#endif
+			break;
+		case MWM_INPUT_SYSTEM_MODAL:
+		case MWM_INPUT_FULL_APPLICATION_MODAL:
+			GrabKind = XtGrabExclusive;
+			break;
+		case MWM_INPUT_MODELESS:
+		default:
+			GrabKind = XtGrabNonexclusive;
+			break;
+		}
+
+		if (GrabKind != XtGrabNone) {
+			LTAddGrab(NULL,
+				GrabKind == XtGrabExclusive ? True : False, False,
+				o, o);
+		}
+		VSEP_GrabKind(nw) = GrabKind;
+		if (GrabRelatives) {
+			LTGrabRelatives(o);
+		}
+	}
+	return False;
 }
 
 
@@ -3288,6 +3385,8 @@ _XmVendorExtRealize(Widget w, XtPointer closure, XtPointer call_data)
 
     DEBUGOUT(_LtDebug(__FILE__, w, "XmVendorExtRealize\n"));
 
+	_XmPickupUnspecifiedPixmaps(XtDisplay(w));
+
     par = ExtObj_LogicalParent(w);
 
     if (!XmIsDisplay(par))
@@ -3476,12 +3575,12 @@ _LtCheckClassOfVendorShell(Widget w)
    This corrects for the (shared) library loading mechanism in OS/2 
    which differs from those on many standard Unix systems.
    The routine should be called before any other function,
-   done by the _DLL_InitTerm-function.
-   On un*x/ELF systems this seems to be ensured by specifying the
-   libs in correct, canonical order on the linker command line.
-   amai (20010112): Well, I once decided to make it static, but
-     this was an error: to call it from a static libXm one
-     may need this symbol.
+   actually done by the _DLL_InitTerm-function.
+   On un*x/ELF systems the problem addressed here seems to be avoided
+   by specifying the libraries in correct, canonical order on the linker
+   command line.
+   amai (20010112): I once decided to make it static, but this was an error:
+   to call it from a static libXm one may need this symbol.
  */
 #ifdef __EMX__
 extern void
@@ -3489,9 +3588,9 @@ _LtXmFixupVendorShell(void)
 {
 
     transientShellWidgetClass->core_class.superclass =
-	(WidgetClass)&vendorShellClassRec;
+       (WidgetClass)&vendorShellClassRec;
     topLevelShellWidgetClass->core_class.superclass =
-	(WidgetClass)&vendorShellClassRec;
+       (WidgetClass)&vendorShellClassRec;
 }
 
 
@@ -3500,8 +3599,8 @@ _DLL_InitTerm(unsigned long mod_handle, unsigned long flag)
 {
     if (flag == 0UL)  /* initialize DLL */
     {
-	_LtXmFixupVendorShell();
-	return 1; /* success */
+	    _LtXmFixupVendorShell();
+	    return 1; /* success */
     }
     else     /* terminate DLL */
     {
