@@ -45,7 +45,7 @@ static void DialogCB(Widget w, XtPointer client_data, XtPointer call_data)
 
 Widget CreateDialog(Widget parent, char *msg, char *deft,
 		    char **buttons, int buttcnt, 
-		    void*(dialogCB)(Widget, XtPointer, XtPointer),
+		    XtCallbackProc dialogCB,
 		    int DialType)
 /*- 
   this routine merely creates a dialog, it dosn't manage it, or wait for a
@@ -143,7 +143,7 @@ int GXDialog(Widget parent, char *msg, char *deft, char *buttons[],
   DialogDone = FALSE;
 
   dial = CreateDialog(parent, msg, deft, buttons, buttcnt, 
-		      (XtPointer)DialogCB, DialType); 
+		      (XtCallbackProc)DialogCB, DialType); 
   /* display the dialog & wait for answer */
   /* moving the pointer to the window and back */
   {
