@@ -28,7 +28,15 @@ main(int argc, char **argv)
   	XmNforeground, fore,
   	NULL);
 
-  XtAppMainLoop(app);
+
+  
+{
+    static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,   57,   73,   78,   31, 0,0,0, /* one */ 
+    };
+    PrintDetails(toplevel,Expected);
+};
+  LessTifTestMainLoop(toplevel);
 
   exit(0);
 }
