@@ -17,7 +17,7 @@ main(int argc, char **argv)
   toplevel = XtVaAppInitialize(&theApp, "toggle1", NULL, 0,
 			       &argc, argv, NULL, NULL);
 
-  butt= XtVaCreateManagedWidget("Button1", xmToggleButtonWidgetClass, toplevel, 
+  butt= XtVaCreateManagedWidget("Button1Button1", xmToggleButtonWidgetClass, toplevel, 
 				XmNindicatorOn, False,
 				XmNfillOnSelect, True,
 				NULL);
@@ -26,7 +26,17 @@ main(int argc, char **argv)
 
   XtRealizeWidget(toplevel);
 
-  XtAppMainLoop(theApp);
+/* Note: the following values are the result of
+ * querying the current geometry.
+ */
+{
+static XtWidgetGeometry Expected[] = {
+   CWWidth | CWHeight            ,    0,    0,   92,   21, 0,0,0, /* Button1Button1 */
+};
+/* toplevel should be replaced with to correct applicationShell */
+PrintDetails(toplevel, Expected);
+}
+LessTifTestMainLoop(toplevel);
 
   exit(0);
 }
